<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Graphics.DirectX.Direct3D11

Windows Runtime (WinRT) APIs for for the `Windows.Graphics.DirectX.Direct3D11` namespace.

This package provides the `winrt.windows.graphics.directx.direct3d11` module.
